import { RouteRecordRaw } from 'vue-router';

export const constantRoutes: RouteRecordRaw[] = [
  {
    name: 'login',
    path: '/login',
    component: () => import('@/views/login/index'),
    meta: {
      title: '登录',
      singleLayout: 'blank'
    }
  },
  {
    name: '/Layout',
    path: '/',
    component: () => import('@/components/layout/index'),
    children: [
      {
        //默认 显示home组件
        path: '',
        name: 'Home',
        component: () => import('@/views/home/index')
      },
      {
        name: 'prepare-lessons',
        path: '/prepare-lessons',
        component: () => import('@/views/prepare-lessons/index'),
        meta: {
          title: '备课',
          singleLayout: 'blank'
        }
      },
      {
        path: '/studentList',
        name: 'studentList',
        component: () => import('@/views/studentList/index'),
        meta: {
          title: '学生列表',
          singleLayout: 'blank'
        }
      },
      {
        path: '/classList',
        name: 'classList',
        component: () => import('@/views/classList/index'),
        meta: {
          title: '班级列表',
          singleLayout: 'blank'
        }
      },

      {
        path: '/xiaoku-ai',
        name: 'xiaoku-ai',
        component: () => import('@/views/xiaoku-ai/index'),
        meta: {
          title: '小酷AI'
        }
      },
      {
        path: '/xiaoku-music',
        name: 'xiaoku-music',
        component: () => import('@/views/xiaoku-music/index'),
        meta: {
          title: '曲谱库'
        }
      },
      {
        path: '/setting',
        name: 'base-setting',
        component: () => import('@/views/setting/index'),
        meta: {
          title: '设置'
        }
      },
      {
        path: '/natural-resources',
        name: 'natural-resources',
        component: () => import('@/views/natural-resources/index'),
        meta: {
          title: '资源'
        }
      }
    ]
  },
  {
    name: 'attend-class',
    path: '/attend-class',
    component: () => import('@/views/attend-class/index'),
    meta: {
      title: '开始上课',
      singleLayout: 'blank'
    }
  },
  {
    name: '404',
    path: '/404',
    component: () => import('@/views/404/index'),
    meta: {
      title: '未找到',
      singleLayout: 'blank'
    }
  },
  // 匹配无效路径的路由
  {
    name: 'not-found',
    path: '/:path(.*)*',
    component: () => import('@/views/404/index'),
    meta: {
      title: '未找到',
      singleLayout: 'blank'
    }
  }
];
