import { defineComponent, reactive, ref } from 'vue';
import styles from '../index.module.less';
import lockIcon from '../images/pwdIcon.png';
import useIcon from '../images/phoneIcon.png';
import {
  useMessage,
  NForm,
  NFormItem,
  NInput,
  NButton,
  NInputGroup
} from 'naive-ui';
import { useRoute, useRouter } from 'vue-router';
import { PageEnum } from '/src/enums/pageEnum';
import { storage } from '@/utils/storage';
import { useUserStore } from '/src/store/modules/users';
interface FormState {
  username: string;
  password: string;
  grant_type: string;
  loginType: string;
  client_id: string;
  client_secret: string;
}

export default defineComponent({
  name: 'codeLogin',
  setup(props, { emit }) {
    const router = useRouter();
    const route = useRoute();
    const formRef = ref();
    const message = useMessage();
    const loading = ref(false);
    const autoLogin = ref(true);
    const LOGIN_NAME = PageEnum.BASE_LOGIN_NAME;
    const showPwd = ref(false);
    const userStore = useUserStore();
    const formInline = reactive({
      username: 'admin',
      password: '123456',
      isCaptcha: true
    });

    const handleSubmit = async () => {
      formRef.value.validate(async (errors: any) => {
        if (!errors) {
          const { username, password } = formInline;
          message.loading('登录中...');
          loading.value = true;

          const params: FormState = {
            username,
            password,
            loginType: 'password',
            grant_type: 'password',
            client_id: 'jmedu-backend',
            client_secret: 'jmedu-backend'
          };

          try {
            await userStore.login(params);
            // return;
            message.destroyAll();
            // if (some.code == ResultEnum.SUCCESS) {
            //  判断是否勾选自动登录
            if (autoLogin.value) {
              storage.set('userInfo', JSON.stringify(formInline));
            } else {
              storage.remove('userInfo');
            }

            // route.query?.redirect ||
            const toPath = decodeURIComponent('/' as string);

            message.success('登录成功，即将进入系统');
            if (route.name === LOGIN_NAME) {
              router.replace('/');
            } else router.replace(toPath);
            // } else {
            //   // message.info(some.msg || "登录失败");
            // }
          } catch (e: any) {
            message.destroyAll();
            loading.value = false;
            message.error(e.msg);
            console.log(e);
          } finally {
            loading.value = false;
          }
        }
      });
    };
    return () => (
      <div class={styles['view-account-form-wrap']}>
        {/* <div class={styles.formTitle}>
      <div class={styles.dot}></div>
      酷乐秀课堂乐器
    </div> */}
        <NForm
          ref={formRef}
          label-placement="left"
          size="large"
          model={formInline}>
          <NFormItem
            path="username"
            rule={[
              { required: true, message: '请输入用户名', trigger: 'blur' }
            ]}>
            <NInput
              v-model:value={formInline.username}
              placeholder="请输入用户名">
              {{
                prefix: () => (
                  <img src={useIcon} class={styles.prefixIcon} alt="" />
                )
              }}
            </NInput>
          </NFormItem>
          <NFormItem
            path="password"
            rule={[{ required: true, message: '请输入密码', trigger: 'blur' }]}>
            <NInputGroup>
              <NInput
                v-model:value={formInline.password}
                type="text"
                showPasswordOn="click"
                placeholder="请输入密码"
                inputProps={{ autocomplete: 'off' }}
                class={styles.sendInput}
                onKeydown={(e: KeyboardEvent) => {
                  if (e.code === 'Enter') {
                    handleSubmit();
                  }
                }}>
                {{
                  prefix: () => (
                    <img src={lockIcon} class={styles.prefixIcon} alt="" />
                  ),
                  suffix: () => (
                    <NButton class={styles.sendMsg}>发送短信</NButton>
                  )
                }}
              </NInput>
            </NInputGroup>
          </NFormItem>

          <NFormItem class={styles['default-color']}>
            <div class={[styles['flex'], styles['justify-between']]}>
              <div class={styles['flex-initial']}>
                {/* <NCheckbox v-model:checked={autoLogin.value}>
                  记住密码
                </NCheckbox> */}
              </div>
            </div>
          </NFormItem>
          <NFormItem>
            <NButton
              class={styles.submitBtm}
              type="primary"
              onClick={handleSubmit}
              size="large"
              disabled={loading.value}
              block>
              立即登录
            </NButton>
          </NFormItem>
        </NForm>
      </div>
    );
  }
});
